{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Blastdbcmd to dump seqs/info.",
            "baseCommand": "blastdbcmd",
            "hints": [
                {
                    "dockerPull": "ncbi/blast",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "BLASTDB",
                            "envValue": "$(inputs.blastdb_dir.path)"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#blastdbcmd_docker.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-db"
                    },
                    "id": "#blastdbcmd_docker.cwl/db_flag"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-entry_batch"
                    },
                    "id": "#blastdbcmd_docker.cwl/entry_batch_flag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-entry"
                    },
                    "id": "#blastdbcmd_docker.cwl/entry_flag"
                },
                {
                    "type": "string",
                    "default": "blastdbcmd.out",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-out"
                    },
                    "id": "#blastdbcmd_docker.cwl/out_flag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-outfmt"
                    },
                    "id": "#blastdbcmd_docker.cwl/outfmt_flag"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-target_only"
                    },
                    "id": "#blastdbcmd_docker.cwl/target_flag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-taxids"
                    },
                    "id": "#blastdbcmd_docker.cwl/taxids_flag"
                }
            ],
            "id": "#blastdbcmd_docker.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_flag)"
                    },
                    "id": "#blastdbcmd_docker.cwl/blastdbcmd_results"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "BLASTP search.",
            "baseCommand": "blastp",
            "hints": [
                {
                    "dockerPull": "ncbi/blast",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "BLASTDB",
                            "envValue": "$(inputs.blastdb_dir.path)"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#blastp_docker.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-db"
                    },
                    "id": "#blastp_docker.cwl/db_flag"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-num_threads"
                    },
                    "id": "#blastp_docker.cwl/num_threads_flag"
                },
                {
                    "type": "string",
                    "default": "blastp.out",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-out"
                    },
                    "id": "#blastp_docker.cwl/out_flag"
                },
                {
                    "type": "string",
                    "default": "6 qaccver saccver bitscore pident qcovhsp qlen length",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-outfmt"
                    },
                    "id": "#blastp_docker.cwl/outfmt_flag"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-query"
                    },
                    "id": "#blastp_docker.cwl/query_flag"
                },
                {
                    "type": "string",
                    "default": "blastp",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-task"
                    },
                    "id": "#blastp_docker.cwl/task_flag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-taxids"
                    },
                    "id": "#blastp_docker.cwl/taxid_flag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_flag)"
                    },
                    "id": "#blastp_docker.cwl/blast_results"
                }
            ],
            "id": "#blastp_docker.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Parses BLAST tabular.",
            "baseCommand": "parse_blast_report.py",
            "inputs": [
                {
                    "type": "int",
                    "label": "produce only IDs",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#parse_blast_report.cwl/idsonly_flag"
                },
                {
                    "type": "File",
                    "label": "BLAST tabular output",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#parse_blast_report.cwl/in_flag"
                },
                {
                    "type": "int",
                    "label": "Length of match",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#parse_blast_report.cwl/length_flag"
                },
                {
                    "type": "string",
                    "default": "parse_blast.tab",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#parse_blast_report.cwl/out_flag"
                },
                {
                    "type": "float",
                    "label": "Min percent ID",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#parse_blast_report.cwl/percent_flag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_flag)"
                    },
                    "id": "#parse_blast_report.cwl/parse_blast_results"
                }
            ],
            "id": "#parse_blast_report.cwl"
        },
        {
            "class": "Workflow",
            "label": "BLASTP, parse, dump FASTA",
            "inputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#main/user_db_dir"
                },
                {
                    "type": "File",
                    "id": "#main/user_fasta_results"
                },
                {
                    "type": "int",
                    "id": "#main/user_idsonly_flag"
                },
                {
                    "type": "int",
                    "id": "#main/user_length_flag"
                },
                {
                    "type": "string",
                    "id": "#main/user_outfmt_flag"
                },
                {
                    "type": "string",
                    "id": "#main/user_parse_results"
                },
                {
                    "type": "float",
                    "id": "#main/user_percent_flag"
                },
                {
                    "type": "File",
                    "id": "#main/user_query"
                },
                {
                    "type": "string",
                    "id": "#main/user_search_db"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/user_target_flag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/blastdbcmd_step/blastdbcmd_results",
                    "id": "#main/blast_out_class"
                }
            ],
            "steps": [
                {
                    "run": "#blastp_docker.cwl",
                    "in": [
                        {
                            "source": "#main/user_db_dir",
                            "id": "#main/blast_step/blastdb_dir"
                        },
                        {
                            "source": "#main/user_search_db",
                            "id": "#main/blast_step/db_flag"
                        },
                        {
                            "source": "#main/user_outfmt_flag",
                            "id": "#main/blast_step/outfmt_flag"
                        },
                        {
                            "source": "#main/user_query",
                            "id": "#main/blast_step/query_flag"
                        }
                    ],
                    "out": [
                        "#main/blast_step/blast_results"
                    ],
                    "id": "#main/blast_step"
                },
                {
                    "run": "#blastdbcmd_docker.cwl",
                    "in": [
                        {
                            "source": "#main/user_db_dir",
                            "id": "#main/blastdbcmd_step/blastdb_dir"
                        },
                        {
                            "source": "#main/user_search_db",
                            "id": "#main/blastdbcmd_step/db_flag"
                        },
                        {
                            "source": "#main/parse_blast_step/parse_blast_results",
                            "id": "#main/blastdbcmd_step/entry_batch_flag"
                        },
                        {
                            "source": "#main/user_target_flag",
                            "id": "#main/blastdbcmd_step/target_flag"
                        }
                    ],
                    "out": [
                        "#main/blastdbcmd_step/blastdbcmd_results"
                    ],
                    "id": "#main/blastdbcmd_step"
                },
                {
                    "run": "#parse_blast_report.cwl",
                    "in": [
                        {
                            "source": "#main/user_idsonly_flag",
                            "id": "#main/parse_blast_step/idsonly_flag"
                        },
                        {
                            "source": "#main/blast_step/blast_results",
                            "id": "#main/parse_blast_step/in_flag"
                        },
                        {
                            "source": "#main/user_length_flag",
                            "id": "#main/parse_blast_step/length_flag"
                        },
                        {
                            "source": "#main/user_parse_results",
                            "id": "#main/parse_blast_step/out_flag"
                        },
                        {
                            "source": "#main/user_percent_flag",
                            "id": "#main/parse_blast_step/percent_flag"
                        }
                    ],
                    "out": [
                        "#main/parse_blast_step/parse_blast_results"
                    ],
                    "id": "#main/parse_blast_step"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
